#
# spec file for package streamdeck-linux-gui
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3

Name:           streamdeck-linux-gui
Version:        4.1.3
Release:        1.2
Summary:        Stream Deck tools (service, Web Interface, and UI)
License:        MIT
URL:            https://streamdeck-linux-gui.github.io/streamdeck-linux-gui/
Source:         https://files.pythonhosted.org/packages/source/s/streamdeck-linux-gui/streamdeck_linux_gui-%{version}.tar.gz
Source1:        70-streamdeck.rules
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-poetry
# SECTION test requirements
BuildRequires:  python3-CairoSVG >= 2.5.2
BuildRequires:  python3-Pillow >= 9.4.0
BuildRequires:  python3-filetype >= 1.0.10
#BuildRequires:  python3-pynput >= 1.7.6
BuildRequires:  python3-pyside6 >= 6.4.2
BuildRequires:  python3-python-xlib >= 0.33
BuildRequires:  python3-streamdeck >= 0.9.5
# /SECTION
BuildRequires:  fdupes
BuildRequires:  udev
Requires:       python3-CairoSVG >= 2.5.2
Requires:       python3-Pillow >= 9.4.0
Requires:       python3-evdev >= 1.3
Requires:       python3-filetype >= 1.0.10
Requires:       python3-importlib-metadata >= 6.8.0
Requires:       python3-pynput >= 1.7.6
Requires:       python3-pyside6 >= 6.4.2
Requires:       python3-python-xlib >= 0.33
Requires:       python3-streamdeck >= 0.9.3
BuildArch:      noarch
Conflicts:      streamdeck-ui
Provides:       streamdeck-ui = %{version}
Obsoletes:      streamdeck-ui < %{version}

%description
A service, Web Interface, and UI for interacting with your computer using a Stream Deck

%prep
%setup -q -n streamdeck_linux_gui-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

install -D -m0644 %{S:1} %{buildroot}%{_udevrulesdir}/70-streamdeck.rules

%files
%{_bindir}/streamdeck
%{_bindir}/streamdeckc
%{python_sitelib}/streamdeck_ui
%{python_sitelib}/streamdeck_linux_gui-*.dist-info
%{_udevrulesdir}/70-streamdeck.rules

%changelog
* Sat Jul 27 2024 Simon Lees <sflees@suse.de>
- update to 4.1.3 (Combined changelog since 4.0.0):
  * replace pynput by evdev (#103) (6424eae)
  * Implemented @invader's PIL Patch (#227) (2461d04)
  * Key image size bug fixes (#188) (c218dc1)
  * add default delay of 0.5 and support floats (70db99e)
  * resolve inability to select buttons in the ui (7451b9f)
  * add back keyboard delay feature (14b6431)
  * handle exception if font can't be set, use fallback (4f2e5d7)
  * only initialize UInput when necessary (6a3beb0)
  * try to write unicode characters using ctrl+shift+u (325a960)
  * set deck_id properly when using streamdeckc (e127d0b)
  * globally initialize UInput (c579687)
  * Handle exception in ImageFilter class (0369bf9)
  * initialize uinput with the event code int constants instead of their names (f76d03e)
  * add fallback font key to sys fonts if missing (90048f5)
  * prefer fallback fonts over system fonts (414e345)
  * Shut down the CLI server on SIGTERM (3c4a2c9)
  * allow button image to update with same selected file path (53e7c7f)
  * Update 60-streamdeck.rules for Streamdeck XL (1101fb9)
  * Update 60-streamdeck.rules for the Stream Deck Plus (#182) (4fb2c7c)
  * Provide udev rules (d0cf475)
  * Remove semaphore file once app terminates (#209) (ed06caa)
* Fri Dec 15 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * ensure correctly initialization of pipeline when new page is
    added
  * Ensure palette frames are RGBA
  * **gui.py:** Fix horizontal alignment
  * make image load exception broader
  * switch page/button state race condition
  * **timers.py:** ensure to disconnect previous calls
  * validate invalid pages and button states
  * Add support for default config
  * Multi state buttons
  * Use dataclasses instead of dicts to handle configuration and
    support multi state buttons.
  * config: state now uses models instead dicts
  * api: state now uses models instead dicts
  * gui: configuration now support multiple button states, v1
    state file will be migrated, v2 is not backward compatible
  * gui: warn dialog about migrating file and backup
  * gui: allow add and remove button states
  * gui: allow set the action "switch state" in button settings
  * gui: cleaner logic to update button states
  * cli: allow set the button state
  * api: add test for add and remove button states
  * api: add test for add and remove pages
  * api: add test for change all properties (font, font size,
    color, etc)
  * gui: add test for all menu items
  * gui: add tests for pages actions (add and remove)
  * gui: add tests for button states actions add and remove
  * gui: add tests for warn migration message
  * config: test read/write and migration configuration
  * fix minor bugs resulting in bad buttons display under some
    circumstances
  * Use dataclasses instead of dicts to handle configuration and
    support multi state buttons.
  * config: state now uses models instead dicts
  * api: state now uses models instead dicts
  * gui: configuration now support multiple button states, v1
    state file will be migrated, v2 is not backward compatible
  * gui: warn dialog about migrating file and backup
  * gui: allow add and remove button states
  * gui: allow set the action "switch state" in button settings
  * gui: cleaner logic to update button states
  * cli: allow set the button state
  * build/ci: add ubuntu libraries for virtual framebuffer
  * build/ci: add python pytest-qt libraries
  * api: add test for add and remove button states
  * api: add test for add and remove pages
  * api: add test for change all properties (font, font size,
    color, etc)
  * gui: add test for all menu items
  * gui: add tests for pages actions (add and remove)
  * gui: add tests for button states actions add and remove
  * gui: add tests for warn migration message
  * config: test read/write and migration configuration
  * fix minor bugs resulting in bad buttons display under some
    circumstances
* Fri Nov 10 2023 Simon Lees <sflees@suse.de>
- Re add provides and conflicts with streamdeck-ui, no idea when
  obs lost those.
* Wed Nov  1 2023 Simon Lees <sflees@suse.de>
- Fork of streamdeck_ui, this package was branched from there
- Update to 3.2.0
  * Features
  * Add background change support (657525b)
  * Add support for Font configuration (#6) (d11b93d)
  * Add support for multiline button labels (0c36284)
  * Add support for numpad keys (#50) (70ff7ad)
  * Operating StreamDeck from a terminal (#37) (37055cf)
  * Bug Fixes
  * Work with Pillow 10.0.0
  * bug during initialization of the socket for communication with CLI commands. (#39) (4057cb0)
  * cli: commands (#46) (da0f08f)
  * gui: Show correct package version on About (6a3e587)
  * wrong monitor un assign (511de2f)
* Wed Jul 26 2023 Frederic Crozat <fcrozat@suse.com>
- Add explicit requires on python3-setuptools.
- Sort dependencies in specfile.
* Sun Apr 23 2023 Frederic Crozat <fcrozat@suse.com>
- Upgrade to 2.0.15.
* Mon Aug  2 2021 Simon Lees <simonf.lees@suse.com>
- Initial Package
